@@ -9,7 +9,7 @@ from msmart.command import base_command as request_status_command
 from msmart.command import set_command
 from msmart.packet_builder import packet_builder
 
-VERSION = '0.1.18'
+VERSION = '0.1.19'
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -158,12 +158,13 @@ class air_conditioning_device(device):
         super().__init__(device_ip, convert_device_id_int(device_id))
         self._prompt_tone = False
         self._power_state = False
-        self._target_temperature = 17
+        self._target_temperature = 17.0
         self._operational_mode = air_conditioning_device.operational_mode_enum.auto
         self._fan_speed = air_conditioning_device.fan_speed_enum.Auto
         self._swing_mode = air_conditioning_device.swing_mode_enum.Off
         self._eco_mode = False
         self._turbo_mode = False
+        self.farenheit_unit = False # default unit is Celcius. this is just to control the temperatue unit of the AC's display. the target_temperature setter always expects a celcius temperature (resolution of 0.5C), as does the midea API
 
         self._on_timer = None
         self._off_timer = None
@@ -183,7 +184,13 @@ class air_conditioning_device(device):
             response = appliance_response(data)
             self._defer_update = False
             self._support = True
-            self.update(response)
+            if data[0xa] != 0xc0:
+                _LOGGER.debug(
+                    "refresh - Not status(0xc0) respone, defer update. {}, {}: {}".format(self.ip, self.id, data[0xa:].hex()))
+                self._defer_update = True
+            if not self._defer_update:
+                self.update(response)
+                self._defer_update = False
 
     def apply(self):
         self._updating = True
@@ -197,8 +204,9 @@ class air_conditioning_device(device):
             cmd.swing_mode = self._swing_mode.value
             cmd.eco_mode = self._eco_mode
             cmd.turbo_mode = self._turbo_mode
-
             pkt_builder = packet_builder(self.id)
+#            cmd.night_light = False
+            cmd.fahrenheit = self.farenheit_unit
             pkt_builder.set_command(cmd)
 
             data = pkt_builder.finalize()
@@ -208,6 +216,10 @@ class air_conditioning_device(device):
             if len(data) > 0:
                 response = appliance_response(data)
                 self._support = True
+                if data[0xa] != 0xc0:
+                    _LOGGER.debug(
+                        "apply - Not status(0xc0) respone, defer update. {}, {}: {}".format(self.ip, self.id, data[0xa:].hex()))
+                    self._defer_update = True
                 if not self._defer_update:
                     self.update(response)
         finally:
@@ -255,10 +267,10 @@ class air_conditioning_device(device):
         return self._target_temperature
 
     @target_temperature.setter
-    def target_temperature(self, temperature: int):
+    def target_temperature(self, temperature_celsius: float): # the implementation later rounds the temperature down to the nearest 0.5'C resolution.
         if self._updating:
             self._defer_update = True
-        self._target_temperature = temperature
+        self._target_temperature = temperature_celsius
 
     @property
     def operational_mode(self):
